
.. blogpost::
    :title: Python + Excel
    :keywords: python, excel, ExcelPython
    :date: 2017-01-02
    :categories: module

    I did not tried but it seems interesting:
    `ExcelPython <http://ericremoreynolds.github.io/excelpython/quickstart/>`_.
    The tutorial looks nice.
